"""
Package gathering all unitary tests for autoplanner.
Module names must start with `test_` to be taken into account.

You should consider to install :mod:`Distribute` to run all tests with::

    $ python setup.py test

"""
import unittest
__author__ = 'Matthieu Gallet'

if __name__ == '__main__':
    unittest.main()
