if(!window.calendar_languages) {
    window.calendar_languages = {};
}

window.calendar_languages['id-ID'] = {
    error_noview: 'Kalender: Tampilan {0} tidak ditemukan',
    error_dateformat: 'Kalender: Format tanggal salah {0}. Seharusnya "now" atau "yyyy-mm-dd"',
    error_loadurl: 'Kalender: URL dari jadwal belum di tentukan',
    error_where: 'Kalender: Arah navigasi salah {0}. Hanya boleh "next" atau "prev" atau "today"',
    error_timedevide: 'Kalender: Parameter perpecahan waktu harus dibagi 60 tanpa desimal. Seperti 10, 15, 30',

    no_events_in_day: 'Tidak ada Jadwal di hari ini.',

    title_year: '{0}',
    title_month: '{0} {1}',
    title_week: 'minggu {0} dari {1}',
    title_day: '{0}, {1} {2} {3}',

    week: 'Minggu {0}',
    all_day: 'Semua hari',
    time: 'Jam',
    events: 'Jadwal',
    before_time: 'Berakhir sebelum waktu',
    after_time: 'Dimulai setelah waktu',

    m0: 'Januari',
    m1: 'Februari',
    m2: 'Maret',
    m3: 'April',
    m4: 'Mei',
    m5: 'Juni',
    m6: 'Juli',
    m7: 'Agustus',
    m8: 'September',
    m9: 'Oktober',
    m10: 'November',
    m11: 'Desember',

    ms0: 'Jan',
    ms1: 'Feb',
    ms2: 'Mar',
    ms3: 'Apr',
    ms4: 'Mei',
    ms5: 'Jun',
    ms6: 'Jul',
    ms7: 'Ags',
    ms8: 'Sep',
    ms9: 'Okt',
    ms10: 'Nov',
    ms11: 'Des',

    d0: 'Minggu',
    d1: 'Senin',
    d2: 'Selasa',
    d3: 'Rabu',
    d4: 'Kamis',
    d5: 'Jumat',
    d6: 'Sabtu',

    first_day: 1,
    week_numbers_iso_8601: true,
    holidays: {
        /* for 2015 */
        '03-01-2015': 'Maulid Nabi Muhammad SAW',
        '19-01-2015': 'Tahun Baru Imlek 2566 Kongzili',
        '21-03-2015': 'Hari Raya Nyepi Tahun Baru Saka 1937',
        '16-05-2015': 'Isra Mikraj Nabi Muhammad SAW',
        '02-06-2015': 'Hari Raya Waisak 2559',
        '17-07-2015': 'Hari Raya Idul Fitri 1436 Hijriah',
        '18-07-2015': 'Hari Raya Idul Fitri 1436 Hijriah',
        '24-09-2015': 'Hari Raya Idul Adha 1436 Hijriah',
        '14-10-2015': 'Tahun Baru Islam 1437 Hijriah',

        '01-01': 'Tahun Baru',
        '01-05': 'Hari Buruh Internasional',
        '17-08': 'Hari Kemerdekaan RI (Independence Day)',
        '25-12': 'Hari Raya Natal',

        'easter-2': 'Jumat Agung',
        'easter': 'Paskah',
        'easter+39': 'Kenaikan Yesus Kristus',
        
        /* for 2016 */
        '08-02-2016': 'Tahun Baru Imlek 2567',
        '28-03-2016': 'Hari Raya Nyepi Tahun Baru Saka 1938',
        '06-05-2016': 'Isra Mikraj Nabi Muhammad SAW 1437 Hijriah',
        '22-05-2016': 'Hari Raya Waisak 2560',
        '06-07-2016': 'Hari Raya Idul Fitri 1437 Hijriah',
        '07-07-2016': 'Hari Raya Idul Fitri 1437 Hijriah',
        '12-09-2016': 'Hari Raya Idul Adha 1437 Hijriah',
        '02-10-2016': 'Tahun Baru Islam 1438 Hijriah',
        '12-12-2016': 'Maulid Nabi Muhammad SAW',

        /* for 2017 */
        '28-01-2017': 'Tahun Baru Imlek 2568',
        '09-03-2017': 'Hari Raya Nyepi Tahun Baru Saka 1939',
        '24-04-2017': 'Isra Mikraj Nabi Muhammad SAW 1438 Hijriah',
        '11-05-2017': 'Hari Raya Waisak 2561',
        '25-06-2017': 'Hari Raya Idul Fitri 1438 Hijriah',
        '26-06-2017': 'Hari Raya Idul Fitri 1438 Hijriah',
        '01-09-2017': 'Hari Raya Idul Adha 1437 Hijriah',
        '21-10-2017': 'Tahun Baru Islam 1439 Hijriah',
        '01-12-2017': 'Maulid Nabi Muhammad SAW'
        
    }
};
