if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['ar-SA'] = {
	error_noview: 'التقويم: العرض {0} غير موجود',
	error_dateformat: 'التقويم: تنسيق خاطئ للتاريخ {0}. يجب أن يكون التاريخ "الآن" أو "yyyy-mm-dd"',
	error_loadurl: 'التقويم: لم يتم تحديد رابط الحدث',
	error_where: 'التقويم: اتجاه تصفح خاطئ {0}. يجب أن يحتوي فقط على "التالي" أو "السابق" أو "اليوم"',
	error_timedevide: 'التقويم: تقسيم الوقت يجب أن يمكن قسمة 60 عليه بدون باقي . مثل 10, 15, 30',

	no_events_in_day: 'لا يوجد أحداث في هذا اليوم',

	title_year: 'العام {0}',
	title_month: '{0} {1}',
	title_week: 'الأسبوع {0} من {1}',
	title_day: '{0} {1} {2}, {3}',

	week:'الأسبوع {0}',
	all_day:     'كامل اليوم',
	time:        'الوقت',
	events:      'الأحداث',
	before_time: 'ينتهي قبل الخط الزمني',
	after_time:  'يبدء بعد الخط الزمني',

	m0: 'يناير',
	m1: 'فبراير',
	m2: 'مارس',
	m3: 'أبريل',
	m4: 'مايو',
	m5: 'يونيو',
	m6: 'يوليو',
	m7: 'أغسطس',
	m8: 'سبتمبر',
	m9: 'أكتوبر',
	m10: 'نوفمبر',
	m11: 'ديسمبر',

	ms0: 'يناير',
	ms1: 'فبراير',
	ms2: 'مارس',
	ms3: 'أبريل',
	ms4: 'مايو',
	ms5: 'يونيو',
	ms6: 'يوليو',
	ms7: 'أغسطس',
	ms8: 'سبتمبر',
	ms9: 'أكتوبر',
	ms10: 'نوفمبر',
	ms11: 'ديسمبر',

	d0: 'السبت',
	d1: 'الأحد',
	d2: 'الإثنين',
	d3: 'الثلاثاء',
	d4: 'الأربعاء',
	d5: 'الخميس',
	d6: 'الجمعة',
	

	first_day: 1,

	holidays: {
	}
};
