{% load autoplanner %}<input type="{{ widget.type }}" name="{{ widget.name }}"{% if widget.value != None %} value="{{ widget.value|timedelta }}"{% endif %}{% include "django/forms/widgets/attrs.html" %} />
