if(!window.calendar_languages) {
	window.calendar_languages = {};
}
window.calendar_languages['ca-ES'] = {
	error_noview:     'Calendari: Vista {0} no trobada',
	error_dateformat: 'Calendari: Format de data invàlid {0}. Ha de ser "now" o "yyyy-mm-dd"',
	error_loadurl:    'Calendari: URL de càrrega d\'esdeveniments no configurada',
	error_where:      'Calendari: Adreça de navegació incorrecta {0}. Els valors correctes són "next" o "prev" o "today"',
	error_timedevide: 'Calendari: paràmetre per al separador d\'hora ha de dividir 60 per un sencer. Per exemple 10, 15, 30',

	no_events_in_day: 'Avui no hi ha esdeveniments',

	title_year:  'Any {0}',
	title_month: '{0} {1}',
	title_week:  'Setmana {0} del {1}',
	title_day:   '{0} {1} {2} {3}',

	week:        'Setmana {0}',
	all_day:     'Tot el dia',
	time:        'Temps',
	events:      'Desenvolupament',
	before_time: 'Temps abans de la línia de temps',
	after_time:  'Fi després d\'una línia de temps',

	m0:  'Gener',
	m1:  'Febrer',
	m2:  'Març',
	m3:  'Abril',
	m4:  'Maig',
	m5:  'Juny',
	m6:  'Juliol',
	m7:  'Agost',
	m8:  'Setembre',
	m9:  'Octubre',
	m10: 'Novembre',
	m11: 'Desembre',

	ms0:  'Gen',
	ms1:  'Feb',
	ms2:  'Març',
	ms3:  'Abr',
	ms4:  'Maig',
	ms5:  'Juny',
	ms6:  'Jul',
	ms7:  'Ag',
	ms8:  'Set',
	ms9:  'Oct',
	ms10: 'Nov',
	ms11: 'Des',

	d0: 'Diumenge',
	d1: 'Dilluns',
	d2: 'Dimarts',
	d3: 'Dimecres',
	d4: 'Dijous',
	d5: 'Divendres',
	d6: 'Dissabte',

	easter:       'Pasqües',
	easterMonday: 'Dilluns de Pasqües',

	first_day: 1,
	week_numbers_iso_8601: true,

	holidays: {
		'01-01':    "Any nou",
		'06-01':    "Dia de Reis",
		'19-03':    "San Josep",
		'easter-3': "Dijous Sant",
		'easter-2': "Divendres Sant",
		'easter':   "Pasqua",
		'easter+1': "Dilluns de Pasqua",
		'01-05':    "Dia del Treballador",
		'15-08':    "Asunció",
		'12-10':    "Festa Nacional d'Espanya",
		'01-11':    "Dia de tots Sants",
		'06-12':    "Día de la Constitución Espanyola",
		'08-12':    "Inmaculada Concepció",
		'25-12':    "Nadal"
	}
};
